@@ -5,28 +5,36 @@
 
 #include <iconv.h>
 
-
+enum {
+	ITEXT_EJ,
+	ITEXT_CHU,
+	ITEXT_RUB,
+	ITEXT_JIS,
+	ITEXT_TES,
+	ITEXT_BTEN,
+	ITEXT_BSEN,
+	ITEXT_SMALL,
+};
 typedef struct ITEXT{
 	unsigned int c1;
 	unsigned int c2;
-	char *utf8;
 
 	char *chu_string;
 
 	int x_off;
 	int y_off;
 
+	int flag;
+
 	int ej;
 	int chu;
 	int rub;
 	int jis;
 	int tes;
-
 	int bouten;
 	int bousen;
 	int small;
 
-
 	struct ITEXT *rubi_head;
 	struct ITEXT *rubi_tail;
 
@@ -37,8 +45,8 @@ typedef struct ITEXT{
 	struct ITEXT *prev;
 }ITEXT_T;
 typedef struct IBUF{
-	unsigned char *buf;
 	int line;
+	int total_line;
 
 	ITEXT_T *i_head;
 	ITEXT_T *i_tail;
@@ -63,15 +71,22 @@ typedef struct BOUTENDATA{
 	unsigned int c1;
 	unsigned int c2;
 }BOUTEN_T;
+typedef struct {
+	char fname[128];
+	char title[128];
+	long c_size;
+	long u_size;
+}IINFO_T;
 
 
 int ibookGetFileData(IBOOK_T **,IBOOK_T **,char *);
-int itextGetTextData(char *,char *,IBUF_T **,IBUF_T **,int);
-int itextDataInsert(ITEXT_T **,ITEXT_T **,unsigned int ,unsigned int,int,int,int,iconv_t);
-int checkRubyString(iconv_t,unsigned char *,int,ITEXT_T **,ITEXT_T **,int *);
-int itextUnZipFile(char *,char *);
+int itextGetTextData(char *,IINFO_T *,IBUF_T **,IBUF_T **,int);
+int itextUnZipFile(char *,char *,IINFO_T *);
+
+
+int itextDataInsert(ITEXT_T **,ITEXT_T **,unsigned int ,unsigned int,int,int,int);
+int checkRubyString(int,ITEXT_T **,ITEXT_T **,int *);
 void itext_data_free(ITEXT_T *);
 void book_link_free(IBOOK_T **,IBOOK_T **);
 int _checkFileType(char *);
-char * euc2utf8(iconv_t,char *,int);
 
