@@ -1,12 +1,15 @@
 #include "itext.h"
 
+#include <sys/stat.h>
 #include <wkf.h>
 
+extern char *XJP_MESSAGE[];
+
 static unsigned char *HEADER_LINE = "---------------------------";
 
 unsigned int SPACE = ' ';
-unsigned int CHU_KEY_C1 = 0xa1;
-unsigned int CHU_KEY_C2 = 0xa6;
+unsigned int CHU_KEY_C1 = 0xa2;
+unsigned int CHU_KEY_C2 = 0xb0;
 
 static IBUF_T *ibuf_data_alloc()
 {
@@ -15,7 +18,6 @@ static IBUF_T *ibuf_data_alloc()
 	it = (IBUF_T *)malloc(sizeof(IBUF_T));
 
 	it->line = 0;
-	it->buf = NULL;
 	it->i_head = NULL;
 	it->i_tail = NULL;
 
@@ -49,7 +51,6 @@ void ibuf_data_free(IBUF_T **start,IBUF_T **end)
 
 		itext_data_free(ib->i_head);
 
-		if(ib->buf != NULL) free(ib->buf);
 		free(ib);
 	}
 
@@ -66,7 +67,6 @@ void itext_data_free(ITEXT_T *ihead)
 
 	for(it=ihead;it!=NULL;it=itt){
 		itt = it->next;
-		if(it->utf8 != NULL) free(it->utf8);
 		if(it->chu_string != NULL) free(it->chu_string);
 		if(it->rubi_head != NULL) itext_data_free(it->rubi_head);
 		if(it->chu_head != NULL) itext_data_free(it->chu_head);
@@ -83,12 +83,13 @@ static ITEXT_T *itext_data_alloc()
 	it = (ITEXT_T *)malloc(sizeof(ITEXT_T));
 	it->c1 = SPACE;
 	it->c2 = SPACE;
-	it->utf8 = NULL;
 	it->chu_string = NULL;
 
 	it->x_off = 0;
 	it->y_off = 0;
 
+	it->flag = 0;
+
 	it->ej = 0;
 	it->chu = 0;
 	it->rub = -1;
@@ -136,15 +137,13 @@ static int _ibuf_add(	IBUF_T **head,
 			IBUF_T **tail,
 			ITEXT_T **ihead,
 			ITEXT_T **itail,
-			unsigned char *s,
 			int i,
 			int line	)
 {
 	IBUF_T *ib;
 
 	ib = (IBUF_T *)ibuf_data_alloc();
-	ib->buf = (unsigned char *)malloc(i + 2);
-	strcpy(ib->buf,s);
+
 	ib->line = line;
 	ib->i_head = *ihead;
 	ib->i_tail = *itail;
@@ -194,24 +193,20 @@ int itextDataInsert(		ITEXT_T **ihead,
 				unsigned int c2,
 				int ej,
 				int chu,
-				int small,
-				iconv_t con		)
+				int small		)
 {
 	ITEXT_T *it;
-	char temp[3],*utf8 = NULL;
+	char temp[3];
 
 	if(ej == 1){
 		temp[0] = c1;
 		temp[1] = c2;
 		temp[2] = '\0';
-
-		utf8 = (char *)euc2utf8(con,temp,2);
 	}
 
 	it = (ITEXT_T *)itext_data_alloc();
 	it->c1 = c1;
 	it->c2 = c2;
-	it->utf8 = utf8;
 	it->ej = ej;
 	it->chu = chu;
 	it->small = small;
@@ -219,15 +214,14 @@ int itextDataInsert(		ITEXT_T **ihead,
 
 	return 0;
 }
-int itextGetTextData(char *fname,char *title,IBUF_T **head,IBUF_T **tail,int ruby_on)
+int itextGetTextData(char *fname,IINFO_T *info,IBUF_T **head,IBUF_T **tail,int ruby_on)
 {
-	iconv_t con;
+	struct stat sbuf;
 
 	FILE *fp;
 	unsigned char *p;
 	unsigned char buf[BUFSIZ];
 	unsigned char buf_euc[BUFSIZ];
-	unsigned char line_str[BUFSIZ];
 
 	IBUF_T *ib;
 	ITEXT_T *it,*rb,*chu;
@@ -238,6 +232,7 @@ int itextGetTextData(char *fname,char *title,IBUF_T **head,IBUF_T **tail,int rub
 	unsigned int c2;
 
 	int slen,i;
+	int total_size = 0;
 	int total_line = 1;
 	int head_line = 0;
 	int file_type;
@@ -256,24 +251,24 @@ int itextGetTextData(char *fname,char *title,IBUF_T **head,IBUF_T **tail,int rub
 		if((fp = fopen(fname,"r")) == NULL) return -1;
 
 	}else if(file_type == 1){
-		if(itextUnZipFile(fname,zipfname) < 0) return -1;
+		if(itextUnZipFile(fname,zipfname,info) < 0) return -1;
 		if((fp = fopen(zipfname,"r")) == NULL) return -1;
 
 	}else if(file_type < 0){
 		return -1;
 	}
+	fstat(fileno(fp),&sbuf);
 
-	con = iconv_open("UTF-8","EUC-JP");
-
+	xtext_usage(NULL,0);
 	while(fgets(buf,BUFSIZ,fp) != NULL){
+		total_size += strlen(buf);
+		xtext_usage(XJP_MESSAGE[7],(double)total_size/sbuf.st_size);
+
 		wkfConvertKanjiCodeOfString(KC_UNKNOWN,buf,KC_EUC,buf_euc,BUFSIZ);
 
 		if(ruby_on && head_line < 30){
 			if(strncmp(buf_euc,HEADER_LINE,strlen(HEADER_LINE)) == 0){
-				if(HEAD)
-					HEAD = 0;
-				else
-					HEAD = 1;
+				HEAD = HEAD ? 0 : 1;
 				head_line++;
 				continue;
 			}
@@ -283,10 +278,9 @@ int itextGetTextData(char *fname,char *title,IBUF_T **head,IBUF_T **tail,int rub
 
 
 		if((slen = _no_k(buf_euc)) == 0){
-			line_str[0] = '\0';
-			_ibuf_add(head,tail,&ihead,&itail,line_str,0,total_line++); 
+			_ibuf_add(head,tail,&ihead,&itail,0,total_line++); 
 		}
-		if(total_line == 1) strcpy(title,buf_euc);
+		if(total_line == 1) strcpy(info->title,buf_euc);
 
 		i=0;
 		for(p=buf_euc;*p;p++){
@@ -294,62 +288,54 @@ int itextGetTextData(char *fname,char *title,IBUF_T **head,IBUF_T **tail,int rub
 				c1 = *p++;
 				c2 = *p;
 
-				/* -- RUBY CHU --*/
 				if(ruby_on){
+
 					if(RUB >= 0) RUB++;
-					if(c1 == 0xa1 && c2 == 0xc3){
-				       		RUB = 0;
-						continue;
+			                if(c1 == 0xa1 && c2 == 0xc3){
+						RUB = 0;
+					        continue;
 					}
-					if(c1 == 0xa1 && c2 == 0xd4){ 
-						if(itail != NULL && RUB >= 0) itail->rub = RUB;
+					if(c1 == 0xa1 && c2 == 0xd4){
+					        if(itail != NULL && RUB >= 0) itail->rub = RUB;
 						RUB = -1;
-						RUBI = 1;
-						continue;
+					        RUBI = 1;
+					        continue;
 					}
-					if(c1 == 0xa1 && c2 == 0xd5 && RUBI){ 
-						RUBI = 0;
-						continue;
+					if(c1 == 0xa1 && c2 == 0xd5 && RUBI){
+                  				RUBI = 0;
+                              			continue;
 					}
 
 					if(c1 == 0xa1 && c2 == 0xce && CHU == 0){
-						if((*(p+1) == 0xa1 && *(p+2) == 0xf4) ||
-						   (*(p+1) == 0xa1 && *(p+2) == 0xf6) ){
+					        if((*(p+1) == 0xa1 && *(p+2) == 0xf4) ||
+				                   (*(p+1) == 0xa1 && *(p+2) == 0xf6) ){
 
-					       		CHU = 1;
+                                                        CHU = 1;
 							continue;
-						}
-					}
-					if(c1 == 0xa1 && c2 == 0xcf && CHU == 1){
-
-						i = checkRubyString(con,line_str,i,&ihead,&itail,&SMALL);
-				       		CHU = 0;
-						continue;
+                                                }
+                                        }
+				        if(c1 == 0xa1 && c2 == 0xcf && CHU == 1){
+						i = checkRubyString(i,&ihead,&itail,&SMALL);
+					        CHU = 0;
+					        continue;
 					}
 				}
 
-				/* ------------ */
-
-
 				if(RUBI){
-					itextDataInsert(&itail->rubi_head,&itail->rubi_tail,c1,c2,1,0,0,con);
-
+					itextDataInsert(&itail->rubi_head,&itail->rubi_tail,c1,c2,1,0,0);
 				}else if(CHU){
 					if(itail != NULL){
-						itextDataInsert(&itail->chu_head,&itail->chu_tail,c1,c2,1,0,0,con);
+						itextDataInsert(&itail->chu_head,&itail->chu_tail,c1,c2,1,0,0);
 					}else{
-						line_str[i++] = CHU_KEY_C1;
-						line_str[i++] = CHU_KEY_C2;
+						i++;i++;
 
-						itextDataInsert(&ihead,&itail,CHU_KEY_C1,CHU_KEY_C2,1,1,SMALL,con);
-						itextDataInsert(&itail->chu_head,&itail->chu_tail,c1,c2,0,0,0,con);
+						itextDataInsert(&ihead,&itail,CHU_KEY_C1,CHU_KEY_C2,1,1,SMALL);
+						itextDataInsert(&itail->chu_head,&itail->chu_tail,c1,c2,0,0,0);
 					}
 
 				}else{
-					line_str[i++] = c1;
-					line_str[i++] = c2;
-
-					itextDataInsert(&ihead,&itail,c1,c2,1,0,SMALL,con);
+					i++;i++;
+					itextDataInsert(&ihead,&itail,c1,c2,1,0,SMALL);
 
 				}
 
@@ -357,37 +343,37 @@ int itextGetTextData(char *fname,char *title,IBUF_T **head,IBUF_T **tail,int rub
 				if(*p == '\t'){
 					int xj;
 					for(xj=0;xj<4;xj++){
-						line_str[i++] = SPACE; 
+						i++;
 						c1 = SPACE;
 						c2 = SPACE;
 
-						itextDataInsert(&ihead,&itail,c1,c2,0,0,SMALL,con);
+						itextDataInsert(&ihead,&itail,c1,c2,0,0,SMALL);
 					}
 				}else{
-					line_str[i++] = *p; 
+					i++;
 					c1 = *p;
 					c2 = SPACE;
 
 					if(CHU)
-						itextDataInsert(&itail->chu_head,&itail->chu_tail,c1,c2,0,0,SMALL,con);
+						itextDataInsert(&itail->chu_head,&itail->chu_tail,c1,c2,0,0,SMALL);
 					else
-						itextDataInsert(&ihead,&itail,c1,c2,0,0,SMALL,con);
+						itextDataInsert(&ihead,&itail,c1,c2,0,0,SMALL);
 				}
 
 			}
 			
 		}
 		if(i > 0){
-			line_str[i] = '\0';
-			_ibuf_add(head,tail,&ihead,&itail,line_str,i,total_line++); 
+			_ibuf_add(head,tail,&ihead,&itail,i,total_line++); 
 		}
 
 	}
 
 	fclose(fp);
-	iconv_close(con);
 
 	if(file_type == 1) unlink(zipfname);
 
+	xtext_usage(NULL,0);
+
 	return total_line;
 }
