@@ -15,6 +15,7 @@ static unsigned char *CHU_BOUSEN_STR = "˵";
 static unsigned char *CHU_JI_STR0 = "Ϥ";
 static unsigned char *CHU_JI_STR1 = "դ";
 static unsigned char *CHU_JI_STR2 = "Ϥ";
+static unsigned char *CHU_JI_STR3 = "";
 
 static unsigned char *CHU_TE_STR0 = "ŷ";
 
@@ -45,7 +46,8 @@ static int _check_jis_no(char *temp)
 	if(strstr(temp,CHU_JI_STR1) != NULL) return 0;
 
 	if(	(p = (unsigned char *)strstr(temp,CHU_JI_STR0)) == NULL &&
-		(p = (unsigned char *)strstr(temp,CHU_JI_STR2)) == NULL	){
+		(p = (unsigned char *)strstr(temp,CHU_JI_STR2)) == NULL	&&
+		(p = (unsigned char *)strstr(temp,CHU_JI_STR3)) == NULL ){
 
 		if((p = (unsigned char *)strstr(temp,CHU_TE_STR0)) == NULL) return -1;
 	}
@@ -107,7 +109,7 @@ static int _check_bousen_type(char *temp)
 
 	return -1; 
 }
-int checkRubyString(iconv_t con,unsigned char *line_str,int i,ITEXT_T **ihead,ITEXT_T **itail,int *small)
+int checkRubyString(int i,ITEXT_T **ihead,ITEXT_T **itail,int *small)
 {
 	ITEXT_T *chu,*it,*chu_head,*chu_tail;
 	ITEXT_T *bt,*bouten_head = NULL, *bouten_tail = NULL;
@@ -148,7 +150,7 @@ int checkRubyString(iconv_t con,unsigned char *line_str,int i,ITEXT_T **ihead,IT
 			}
 
 			if(flag){
-			       	itextDataInsert(&bouten_head,&bouten_tail,chu->c1,chu->c2,0,0,0,con);
+			       	itextDataInsert(&bouten_head,&bouten_tail,chu->c1,chu->c2,0,0,0);
 			}
 		}
 		if(bouten_head == NULL) goto add_string;
@@ -186,7 +188,8 @@ int checkRubyString(iconv_t con,unsigned char *line_str,int i,ITEXT_T **ihead,IT
 			}
 			if(	strstr(temp,CHU_JI_STR0) != NULL	|| 
 				strstr(temp,CHU_JI_STR1) != NULL	||
-				strstr(temp,CHU_JI_STR2) != NULL	){
+				strstr(temp,CHU_JI_STR2) != NULL	||
+				strstr(temp,CHU_JI_STR3) != NULL	){
 
 				(*itail)->jis = (int)_check_jis_no(temp);
 				return i;
@@ -204,12 +207,7 @@ int checkRubyString(iconv_t con,unsigned char *line_str,int i,ITEXT_T **ihead,IT
 
 add_string :
 	for(chu=chu_head;chu!=NULL;chu=chu->next){
-
-		*(line_str + (i++)) = chu->c1;
-		*(line_str + (i++)) = chu->c2;
-
-		itextDataInsert(ihead,itail,chu->c1,chu->c2,1,1,*small,con);
-
+		itextDataInsert(ihead,itail,chu->c1,chu->c2,1,1,*small);
 	}
 	return i;
 }
