@@ -1,6 +1,8 @@
 #include "itext.h"
 #include "unzip.h"
 
+#include <pwd.h>
+
 static int _unzipLog(char *s)
 {
 	FILE *fp;
@@ -25,7 +27,7 @@ static int _checkFileType_u(char *fname)
 
 	return 0;
 }
-int itextUnZipFile(char *file_path,char *get_file_path)
+int itextUnZipFile(char *file_path,char *get_file_path,IINFO_T *info)
 {
 	char log[100];
 
@@ -65,22 +67,29 @@ int itextUnZipFile(char *file_path,char *get_file_path)
 	for(i=0;i<ginfo.number_entry;i++){
 
 		unzGetCurrentFileInfo(fz,&finfo,filename,sizeof(filename),NULL,0,NULL,0);
-
 		if(_checkFileType_u(filename)){
 			FILE *fp;
+			struct passwd *pwd;
 
-			sprintf(get_file_path,"./%s",filename);
+			strcpy(info->fname,filename);
+			info->c_size = finfo.compressed_size;
+			info->u_size = finfo.uncompressed_size;
+
+			pwd = getpwuid(getuid());
+			sprintf(get_file_path,"%s/%s",pwd->pw_dir,filename);
 			if((fp = fopen(get_file_path,"wb")) == NULL){
 				sprintf(log,"unzip : False Open File (%s)",get_file_path);
 				_unzipLog(log);
 				return -1;
 			}
 
-			unzOpenCurrentFile(fz);
+			xtext_usage(NULL,0);
 
+			unzOpenCurrentFile(fz);
 			un_buf = (void *)malloc(BUFSIZ);
 			while((un_size = unzReadCurrentFile(fz,un_buf,BUFSIZ)) > 0){
 
+				xtext_usage("ǡĹ",(double)un_size/finfo.uncompressed_size);
 				fwrite(un_buf,un_size,1,fp);
 
 			}
@@ -88,6 +97,8 @@ int itextUnZipFile(char *file_path,char *get_file_path)
 			unzCloseCurrentFile(fz);
 			fclose(fp);
 
+			xtext_usage(NULL,0);
+
 			break;
 		}
 
