@@ -11,7 +11,7 @@
 #ifndef __XTEXT_
 
 #define XTEXT_NAME 	"xjp-text"
-#define XTEXT_VERSION 	"1.2.7"
+#define XTEXT_VERSION 	"1.2.9_2"
 #define CONF_DIR_NAME 	".xtext"
 #define CONF_FILE_NAME 	"xtext.conf"
 #define SIORI_FILE_NAME "xtext.siori"
@@ -34,29 +34,21 @@ enum {
 typedef struct{
 	int main_window_width;
 	int main_window_height;
-	char main_window_color[50];
-	char main_font_color[50];
-	char main_shadow_color[50];
-	char rubi_font_color[50];
-	char menu_window_color[50];
-	char menu_font_color[50];
-	char select_window_color[50];
-	char select_font_color[50];
-	char select_font_background_color[50];
-	char main_font_j[100];
-	char main_font_s[100];
-	char main_font_e[100];
-	char book_dir[100];
-	char rubi_font[100];
-
-	int anti;
-	int title_on;
-	int ruby_on;
-	int page_on;
-	int kinsc;
-	int chuki;
-	int line_space;
-	int row_space;
+	char *main_window_img;
+	char *main_window_color;
+	char *main_font_color;
+	char *main_shadow_color;
+	char *rubi_font_color;
+	char *menu_window_color;
+	char *menu_font_color;
+	char *select_window_color;
+	char *select_font_color;
+	char *select_font_background_color;
+	char *main_font_j;
+	char *main_font_s;
+	char *main_font_e;
+	char *book_dir;
+	char *rubi_font;
 
 	char page_next[10];
 	char page_prev[10];
@@ -70,6 +62,15 @@ typedef struct{
 	char chuki_key[10];
 	char page_key[10];
 
+	int anti;
+	int title_on;
+	int ruby_on;
+	int page_on;
+	int kinsc;
+	int chuki;
+	int line_space;
+	int row_space;
+
 }xtext_conf_t;
 typedef struct{
 	Window win;
@@ -268,48 +269,29 @@ int xtext_Init_Text(Display *,my_window_t *,IBUF_T *,char_data_t *);
 int xtext_Draw_Text(Display *,my_window_t *,IBUF_T *,char_data_t *,page_data_t *);
 
 int xtext_Draw_Help(Display *,my_window_t *,xtext_conf_t *);
-
-char * xtextSubWindow(Display *,my_window_t,sub_window_t *,sub_window_t *);
-
+char *xtextSubWindow(Display *,my_window_t,sub_window_t *,sub_window_t *);
 int xtextSubWindow_Message(Display *,my_window_t,char *);
 
 
+int xtext_conf_data(xtext_conf_t *,xtext_conf_t);
 int xtext_next_kuten(ITEXT_T *,int);
 int xtext_prev_kuten(ITEXT_T *,int);
-
 int xtext_get_low_space(ITEXT_T *,char_data_t *);
 int xtext_get_low_pos(ITEXT_T *,char_data_t *,int,int);
-
 int xtextHelpData2Sub(sub_window_t **,sub_window_t **,xtext_conf_t *);
-
 int xtextSioriData2Sub(sub_window_t **,sub_window_t **,xtext_siori_t *);
-
 int xtextBookData2Sub(sub_window_t **,sub_window_t **,char *);
-
 int xtextClearChuMessage(Display *,my_window_t *);
-
 int xtextDrawChuMessage(Display *,my_window_t *,char_data_t *);
-
 int xtextChuMessage(Display *,my_window_t *,char_data_t *,char *);
-
-int xtext_conf_data(xtext_conf_t *,xtext_conf_t);
-
+void xtext_usage(char *,double);
 int xtext_conf_change(void *,int);
-
 int xtext_conf_quit(void *,int);
-
 int xtext_conf_save(void *,int);
-
 char *xtext_Selector_Window(char *,int);
-
 int xtext_font_J2E(char *,char *);
-
 int parse_xlfd_No(char *,char *,int);
-
 int xtext_offt_data(offset_data_t **,offset_data_t **);
-
 int xtext_offt_set(offset_data_t *,offset_data_t *,xtext_conf_t,offset_data_t **,offset_data_t **);
-
 int xtext_set_offset(IBUF_T *,IBUF_T *,offset_data_t *);
-
 int _select_book_data(char *);
