@@ -1,5 +1,5 @@
 /********************************
- * 2005/3/28
+ * 2005/4/7
  * *****************************/
 
 #include "xtext.h"
@@ -8,6 +8,9 @@
 #include <locale.h>
 
 #define debug 0
+
+iconv_t XJP_CONV;
+
 char *XJP_CTRL_STR[] = {
                 "",
                 "",
@@ -26,6 +29,8 @@ char *XJP_MESSAGE[] = {
 	"ǡ顼ȯޤ",
         "ե륨顼ȯޤ",
 	"Level",
+	"ǡɹ",
+	"ǡ"
 };
 char *SEIKEI_LEVEL = NULL;
 char *SELECTOR_BACKGROUND_COLOR = NULL;
@@ -49,6 +54,7 @@ static sub_window_t *help_head = NULL, *help_tail = NULL;
 static ctl_window_t *ctl_head = NULL, *ctl_tail = NULL;
 
 static IBUF_T *line_head = NULL, *line_tail = NULL;
+static IINFO_T ibook_info;
 static offset_data_t *offset_head = NULL, *offset_tail = NULL;
 static offset_data_t *off_head = NULL, *off_tail = NULL;
 static page_data_t *char_p;
@@ -72,6 +78,7 @@ static char_data_t char_d = {
 static xtext_conf_t xconf_default = {
 	500,
 	400,
+	NULL,
 	"lavender",
 	"Black",
 	"gray60",
@@ -86,14 +93,6 @@ static xtext_conf_t xconf_default = {
 	"-misc-*-*-*-*-*-12-*-*-*-*-*-*-*",
 	"/home/***/***/book/",
 	"-misc-*-*-*-*-*-10-*-*-*-*-*-*-*",
-	0,
-	1,
-	1,
-	1,
-	1,
-	0,
-	0,
-	1,
 	"Down",
 	"Up",
 	"h",
@@ -104,7 +103,15 @@ static xtext_conf_t xconf_default = {
 	"Tab",
 	"k",
 	"c",
-	"p"	
+	"p",	
+	0,
+	1,
+	1,
+	1,
+	1,
+	0,
+	0,
+	1
 };
 static xtext_conf_t xconf;
 
@@ -133,13 +140,65 @@ static void _usage()
   -p <num>   Line Space (Pixel)\n \
   -q <num>   Row Space (Pixel)\n \
   -r         Display Book_Title ?\n \
+  -s	     Display Page_No ? \n \
+  -t	     Display Ruby_Char ? \n \
 					 ");
 	fprintf(stderr,"\n");
 
 	exit(1);
 }	
+void xtext_usage(char *usage,double per)
+{
+	static Window uwin = 0;
+	static int width,w,h;
+	int len;
 
+	if(usage == NULL){
+		if(uwin == 0){
+			XRectangle ink,log;
+			char *base = "";
+			int x,y;
 
+			XClearWindow(disp,main_win.win);
+			XmbTextExtents(main_win.fs_s,base,strlen(base),&ink,&log);
+
+			w = main_win.width / 2;
+			h = log.height * 2;
+			x = main_win.width / 4;
+			y = (main_win.height - h) / 2;
+
+			uwin = XCreateSimpleWindow(disp,main_win.win,x,y,w,h,1,main_win.fg_pixel,main_win.bg_pixel);
+
+			XMapRaised(disp,uwin);
+		}else{
+			XDestroyWindow(disp,uwin);
+			uwin = 0;
+		}
+	}else{
+		if(uwin == 0) return;
+		if(width == 0){
+			XRectangle ink,log;
+			len = strlen(usage);
+			XmbTextExtents(main_win.fs_s,usage,len,&ink,&log);
+			width = log.width;
+		}else{
+			len = strlen(usage);
+		}
+
+		XmbDrawString(disp,uwin,main_win.fs_s,main_win.fgc,(w-width)/2,h/2-2,usage,len);
+		if(per){
+			int x,x1,y,y1;
+			x=2;
+			y=h/2+2;
+			y1=h/4;
+
+			x1 = (w-4) * (double)per;
+			XFillRectangle(disp,uwin,main_win.fgc,x,y,x1,y1);
+		}
+
+	}
+
+}
 static void _set_title(Window win,char *str)
 {
 	if(str == NULL) return;
@@ -160,15 +219,21 @@ static void _set_win()
 	XClearWindow(disp,main_win.win);
 	XClearWindow(disp,main_win.cwin);
 	XClearWindow(disp,main_win.mwin);
+
+}
+static void _x_end()
+{
+	iconv_close(XJP_CONV);
+
+	if(main_win.win) XDestroyWindow(disp,main_win.win);
+	XCloseDisplay(disp);
 }
 static void _x_init()
 {
-	iconv_t con;
-
 	setlocale(LC_ALL,"");
-	con = iconv_open("UTF-8","EUC-JP");
-	SEIKEI_LEVEL = (char *)euc2utf8(con,XJP_MESSAGE[6],strlen(XJP_MESSAGE[6]));
-	iconv_close(con);
+	XJP_CONV = iconv_open("UTF-8","EUC-JP");
+
+	SEIKEI_LEVEL = (char *)euc2utf8(XJP_CONV,XJP_MESSAGE[6],strlen(XJP_MESSAGE[6]));
 
 	disp = XOpenDisplay(NULL);
 	root = DefaultRootWindow(disp);
@@ -267,14 +332,27 @@ static void _set_col()
 
 
 #if HAVE_LIBXFT
+
+
 	XftColorAllocName(disp,main_win.visual,main_win.cmap,xconf.main_window_color,&(main_win.bg_color));
+	/*
 	main_win.bg_color.color.alpha = 0xFFFF;
+	*/
 
 	XftColorAllocName(disp,main_win.visual,main_win.cmap,xconf.main_font_color,&(main_win.fg_color));
-	main_win.fg_color.color.alpha = 0xFFFF;
+	/*
+	main_win.fg_color.color.alpha = 0xCCCC;
+	*/
+	/*
+	main_win.fg_color.color.red = 0x0000;
+	main_win.fg_color.color.green = 0x0000;
+	main_win.fg_color.color.blue = 0xFFFF;
+	*/
 
 	XftColorAllocName(disp,main_win.visual,main_win.cmap,xconf.rubi_font_color,&(main_win.rubi_color));
-	main_win.rubi_color.color.alpha = 0xCCCC;
+	/*
+	main_win.rubi_color.color.alpha = 0xFFFF;
+	*/
 #endif
 
 	SELECTOR_BACKGROUND_COLOR = (char *)xconf.select_window_color;
@@ -324,6 +402,11 @@ static void _set_chr()
 	char_d.xpad = xconf.line_space != -1 ? xconf.line_space:0;
 	char_d.ypad = xconf.row_space != -1 ? xconf.row_space:0;
 }
+static void _set_pix()
+{
+	if(xconf.main_window_img == NULL) return;
+
+}
 static void _set_xconf_data()
 {
 	_set_utl();
@@ -331,6 +414,7 @@ static void _set_xconf_data()
 	_set_win();
 	_set_fnt();
 	_set_chr();
+	_set_pix();
 
 	return ;
 }
@@ -359,43 +443,43 @@ static page_data_t *_set_redraw_text()
 }
 static int _init_book_data(char *book_name,int n)
 {
-	iconv_t con;
 	char *utf8;
-	unsigned char title[256];
+	int total_line;
 
-#if debug
-fprintf(stderr,"main_bookname : %s %d\n",book_name,n);
-#endif
 
 	NPC = n;
 
 	if(line_head != NULL) ibuf_data_free(&line_head,&line_tail);
 	if(char_d.book != NULL) free(char_d.book);
 
-	con = iconv_open("UTF-8","EUC-JP");
 	char_d.book = (book_data_t *)malloc(sizeof(book_data_t));
 
-	if(itextGetTextData(book_name,title,&line_head,&line_tail,xconf.ruby_on)<0) return -1;
+	if((total_line = itextGetTextData(book_name,&ibook_info,&line_head,&line_tail,xconf.ruby_on))<0) return -1;
+
+	/*
+	printf("%s\n",ibook_info.fname);
+	printf("%s\n",ibook_info.title);
+	printf("%d\n",ibook_info.c_size);
+	printf("%d\n",ibook_info.u_size);
+	*/
+
+	line_head->total_line = total_line;
 	xtext_set_offset(line_head,line_tail,off_head);
 
-#if debug
-fprintf(stderr,"main_booktitle : %s\n",title);
-#endif
-	utf8 = (char *)euc2utf8(con,title,strlen(title));
+
+	utf8 = (char *)euc2utf8(XJP_CONV,ibook_info.title,strlen(ibook_info.title));
 
 	strcpy(char_d.book->book_path,book_name);
-	strcpy(char_d.book->book_title,title);
+	strcpy(char_d.book->book_title,ibook_info.title);
 	strcpy(char_d.book->book_title_utf8,utf8);
 
 	char_p = (page_data_t *)_set_redraw_text();
 
 	XStoreName(disp,main_win.win,book_name);
 
-	if(utf8) free(utf8);
-	iconv_close(con);
+	if(utf8 != NULL) free(utf8);
 
 	return 0;
-
 }
 static int _help_book_data()
 {
@@ -413,24 +497,18 @@ int _select_book_data(char *book_dir)
 {
 	char *book_path;
 
-#if debug
-fprintf(stderr,"main_selectdir : %s\n",book_dir);
-#endif
 	xtextBookData2Sub(&book_head,&book_tail,book_dir);
 
 	if(book_head == NULL){
 		xtextSubWindow_Message(disp,main_win,XJP_MESSAGE[1]);
 		return -1;
 	}
-
 	if((book_path = (char *)xtextSubWindow(disp,main_win,book_head,book_tail)) == NULL)
 		return -1;
 
 
 	if(strcmp(book_path,XJP_CANCEL) == 0) return -1;
-#if debug
-fprintf(stderr,"main_selectpath : %s\n",book_dir);
-#endif
+
        	_init_book_data(book_path,0);
 
 	return 1;
@@ -543,7 +621,9 @@ static int _conf_win()
 }
 static int _bookmark_win()
 {
-   	if(xtext_siori_data_mark(&siori_head,&siori_tail,char_d.book->book_path,char_d.book->book_title,NPC) < 0) return -1;;
+
+   	if(xtext_siori_data_mark(&siori_head,&siori_tail,char_d.book->book_path,char_d.book->book_title,NPC) < 0) return -1;
+
 	xtextSubWindow_Message(disp,main_win,XJP_MESSAGE[0]);
 
 	return 1;
@@ -777,22 +857,24 @@ static char * _get_option(int c,char **v)
 		switch(option){
 			case 'h': _usage(); break;
 			case 'f':return optarg;break;
-			case 'd':strcpy(xconf.book_dir,optarg);break;
+			case 'd':_xconf_malloc(&xconf.book_dir,optarg);break;
 			case 'a':xconf.main_window_width = atoi(optarg);break;
 			case 'b':xconf.main_window_height = atoi(optarg);break;
-			case 'c':strcpy(xconf.main_window_color,optarg);break;
-			case 'e':strcpy(xconf.main_font_color,optarg);break;
-			case 'g':strcpy(xconf.rubi_font_color,optarg);break;
-			case 'i':strcpy(xconf.menu_font_color,optarg);break;
-			case 'j':strcpy(xconf.menu_window_color,optarg);break;
-			case 'k':strcpy(xconf.main_font_j,optarg);break;
-			case 'l':strcpy(xconf.main_font_s,optarg);break;
-			case 'm':strcpy(xconf.main_font_e,optarg);break;
-			case 'n':strcpy(xconf.rubi_font,optarg);break;
+			case 'c':_xconf_malloc(&xconf.main_window_color,optarg);break;
+			case 'e':_xconf_malloc(&xconf.main_font_color,optarg);break;
+			case 'g':_xconf_malloc(&xconf.rubi_font_color,optarg);break;
+			case 'i':_xconf_malloc(&xconf.menu_font_color,optarg);break;
+			case 'j':_xconf_malloc(&xconf.menu_window_color,optarg);break;
+			case 'k':_xconf_malloc(&xconf.main_font_j,optarg);break;
+			case 'l':_xconf_malloc(&xconf.main_font_s,optarg);break;
+			case 'm':_xconf_malloc(&xconf.main_font_e,optarg);break;
+			case 'n':_xconf_malloc(&xconf.rubi_font,optarg);break;
 			case 'o':xconf.anti = 1;
 			case 'p':xconf.line_space = atoi(optarg);break;
 			case 'q':xconf.row_space = atoi(optarg);break;
 			case 'r':xconf.title_on = 1;break;
+			case 's':xconf.page_on = 1;break;
+			case 't':xconf.ruby_on = 1;break;
 			default: _usage(); break;
 		}
 	}
@@ -813,6 +895,7 @@ int main(int argc,char *argv[])
 	_set_ctrl(&ctl_head,&ctl_tail);
 
 	_x_init();
+
 	_x_drawable();
 	_set_xconf_data();
 
@@ -821,18 +904,25 @@ int main(int argc,char *argv[])
 	while(loop){
 		while(XPending(disp)){
 			XNextEvent(disp,&ev);
+
 			if(ev.xany.window == main_win.win){
 				loop = _xtext_main_event(ev);
+
 			}else if(ev.xany.window == main_win.cwin){
 				loop = _xtext_cwin_event(ev);
+
 			}else if(ev.xany.window == main_win.mwin){
 				_xtext_mwin_event(ev);
+
 			}
+			usleep(500);
 		}
 		usleep(500);
 	}
 	xtext_siori_data_write(&siori_head,&siori_tail);
 
+	_x_end();
+
 	return 0;
 }
 
