@@ -2,15 +2,33 @@
 #include <ctype.h>
 
 
+void euc2utf8_c(iconv_t con,char *to,char *from,int from_len)
+{
+	char *utf8,*utf;
+	char *euc;
+	int euc_len,utf8_len;
+
+	euc_len = from_len;
+	utf8_len = from_len * 2;
+
+	euc = from;
+	utf8 = (char *)malloc(utf8_len);
+	memset(utf8,0,utf8_len);
+
+	utf = utf8;
+	iconv(con,&euc,&euc_len,&utf8,&utf8_len);
+
+	strcpy(to,utf);
+	free(utf);
+
+}
 char * euc2utf8(iconv_t con,char *str,int len)
 {
 	char *euc,*utf8,*utf;
 	int euc_len,utf8_len;
 
 	euc_len = len;
-
-	euc = (char *)malloc(euc_len + 1);
-	memcpy(euc,str,len);
+	euc = str;
 
 	utf8_len = len * 2;
 	utf8 = (char *)malloc(utf8_len);
@@ -57,6 +75,20 @@ unsigned int xstring2uint(char *str)
 
 	return f;
 }
+int itextFlag(ITEXT_T *it,int type,int on)
+{
+	if(it == NULL) return -1;
+
+	if(on)
+		it->flag |= (1 << type);
+	else
+		it->flag &= ~(1 << type);
+
+
+	return 0;
+}
+
+
 
 
 
